[evolution-mapi] Bug #690433 - Do not refresh folder on every message transfer



commit eb1b73cb8510cf01415dd15f23d2901e52615569
Author: Milan Crha <mcrha redhat com>
Date:   Tue Mar 12 17:05:40 2013 +0100

    Bug #690433 - Do not refresh folder on every message transfer

 src/camel/camel-mapi-folder.c |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/src/camel/camel-mapi-folder.c b/src/camel/camel-mapi-folder.c
index dcf1267..7031899 100644
--- a/src/camel/camel-mapi-folder.c
+++ b/src/camel/camel-mapi-folder.c
@@ -1920,8 +1920,10 @@ mapi_folder_transfer_messages_to_sync (CamelFolder *source,
 
        g_object_unref (conn);
 
-       /* update the destination folder to notice new messages */
-       if (success)
+       /* update destination folder only if not frozen, to not update
+          for each single message transfer during filtering
+        */
+       if (success && !camel_folder_is_frozen (destination))
                success = mapi_folder_refresh_info_sync (destination, cancellable, error);
 
        return success;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]